@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 from fastapi import APIRouter, Depends, HTTPException
 from meilisearch_python_async import Client
@@ -10,6 +10,7 @@ from meilisearch_fastapi._config import MeiliSearchConfig, get_config
 from meilisearch_fastapi.models.document_info import (
     DocumentDelete,
     DocumentInfo,
+    DocumentInfoAutoBatch,
     DocumentInfoBatches,
 )
 
@@ -26,6 +27,25 @@ async def add_documents(
         return await index.add_documents(document_info.documents, document_info.primary_key)
 
 
+@router.post("/auto-batch", response_model=List[UpdateId], status_code=202)
+async def add_documents_auto_batch(
+    document_info: DocumentInfoAutoBatch, config: MeiliSearchConfig = Depends(get_config)
+) -> list[UpdateId]:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
+        index = client.index(document_info.uid)
+
+        if document_info.max_payload_size:
+            return await index.add_documents_auto_batch(
+                document_info.documents,
+                max_payload_size=document_info.max_payload_size,
+                primary_key=document_info.primary_key,
+            )
+
+        return await index.add_documents_auto_batch(
+            document_info.documents, primary_key=document_info.primary_key
+        )
+
+
 @router.post("/batches", response_model=List[UpdateId], status_code=202)
 async def add_documents_in_batches(
     document_info: DocumentInfoBatches, config: MeiliSearchConfig = Depends(get_config)
@@ -79,10 +99,21 @@ async def get_document(
 
 
 @router.get("/{uid}", response_model=List[Dict])
-async def get_documents(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> list[dict]:
+async def get_documents(
+    uid: str,
+    limit: int = 20,
+    offset: int = 0,
+    attributes_to_retrieve: Optional[str] = None,
+    config: MeiliSearchConfig = Depends(get_config),
+) -> list[dict]:
     async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
-        documents = await index.get_documents()
+
+        documents = await index.get_documents(
+            offset=offset,
+            limit=limit,
+            attributes_to_retrieve=attributes_to_retrieve,
+        )
 
         if documents is None:
             raise HTTPException(404, "No documents found")
@@ -100,6 +131,25 @@ async def update_documents(
         return await index.update_documents(document_info.documents, document_info.primary_key)
 
 
+@router.put("/auto-batch", response_model=List[UpdateId], status_code=202)
+async def update_documents_auto_batch(
+    document_info: DocumentInfoAutoBatch, config: MeiliSearchConfig = Depends(get_config)
+) -> list[UpdateId]:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
+        index = client.index(document_info.uid)
+
+        if document_info.max_payload_size:
+            return await index.update_documents_auto_batch(
+                document_info.documents,
+                max_payload_size=document_info.max_payload_size,
+                primary_key=document_info.primary_key,
+            )
+
+        return await index.update_documents_auto_batch(
+            document_info.documents, primary_key=document_info.primary_key
+        )
+
+
 @router.put("/batches", response_model=List[UpdateId], status_code=202)
 async def update_documents_in_batches(
     document_info: DocumentInfoBatches, config: MeiliSearchConfig = Depends(get_config)
