@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from async_search_client import Client
-from async_search_client.models import SearchResults
 from fastapi import APIRouter, Depends
+from meilisearch_python_async import Client
+from meilisearch_python_async.models import SearchResults
 
 from meilisearch_fastapi._config import MeiliSearchConfig, get_config
 from meilisearch_fastapi.models.search_parameters import SearchParameters
@@ -14,7 +14,7 @@ router = APIRouter()
 async def search(
     search_parameters: SearchParameters, config: MeiliSearchConfig = Depends(get_config)
 ) -> SearchResults:
-    async with Client(url=config.url, api_key=config.api_key) as client:
+    async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(search_parameters.uid)
 
         return await index.search(
